from .tpu import (
    splash_flash_attention_kernel as splash_flash_attention_kernel,
    SplashAttentionKernel as SplashAttentionKernel,
    BlockSizes as BlockSizes,
    attention_reference as attention_reference,
    Mask as Mask,
    LocalMask as LocalMask,
    make_local_attention_mask as make_local_attention_mask,
    make_causal_mask as make_causal_mask,
    make_random_mask as make_random_mask,
    FullMask as FullMask,
    NumpyMask as NumpyMask,
    CausalMask as CausalMask,
    MultiHeadMask as MultiHeadMask,
    MaskInfo as MaskInfo,
    process_mask as process_mask,
    process_mask_dkv as process_mask_dkv
)



from .adamw import (
    get_adamw_with_cosine_scheduler,
    get_adamw_with_warm_up_cosine_scheduler,
    get_adamw_with_warmup_linear_scheduler,
    get_adamw_with_linear_scheduler
)
from .lion import (
    get_lion_with_cosine_scheduler,
    get_lion_with_with_warmup_linear_scheduler,
    get_lion_with_warm_up_cosine_scheduler,
    get_lion_with_linear_scheduler
)
from .adafactor import (
    get_adafactor_with_cosine_scheduler,
    get_adafactor_with_warm_up_cosine_scheduler,
    get_adafactor_with_warmup_linear_scheduler,
    get_adafactor_with_linear_scheduler
)

from .rmsprop import (
    get_rmsprop_with_cosine_scheduler,
    get_rmsprop_with_linear_scheduler,
    get_rmsprop_with_warmup_linear_scheduler,
    get_rmsprop_with_warm_up_cosine_scheduler
)

from .optimizer_utils import optax_add_scheduled_weight_decay



"""
# File: __init__.py

## Purpose:
This file contains imports for various attention mechanisms used in our project.
"""

from .efficient_attention import efficient_attention as efficient_attention
from .flash_attention import (
    flash_attention as tpu_flash_attention,
    mha as gpu_flash_attention,
    BlockSizes
)
from .splash_attention import (
    splash_flash_attention_kernel as splash_flash_attention_kernel,
    SplashAttentionKernel as SplashAttentionKernel,
    BlockSizes as BlockSizes,
    Mask as Mask,
    LocalMask as LocalMask,
    make_local_attention_mask as make_local_attention_mask,
    FullMask as FullMask,
    NumpyMask as NumpyMask,
    CausalMask as CausalMask,
    MultiHeadMask as MultiHeadMask,
    MaskInfo as MaskInfo,
)
